;; Generated package description from beframe.el  -*- no-byte-compile: t -*-
(define-package "beframe" "1.2.1" "Isolate buffers per frame" '((emacs "28.1")) :commit "ae7aaf8bcfa2b7883a8b9401bcb76f53324f6409" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/beframe")
